==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QAudioDecoderControl_shell.h <==
#ifndef QAUDIODECODERCONTROL_SHELL_H
#define QAUDIODECODERCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qaudiodecodercontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qaudiobuffer.h>
#include <QtMultimedia/qaudiodecoder.h>
#include <QtMultimedia/qaudioformat.h>
#include <QtJambi/RegistryAPI>


class QAudioDecoderControl_shell : public QAudioDecoderControl, public QtJambiShellInterface
{
public:
    QAudioDecoderControl_shell(QObject* parent0 = nullptr);
    ~QAudioDecoderControl_shell() override;

    QAudioFormat audioFormat() const override;
    bool bufferAvailable() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    qint64 duration() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    qint64 position() const override;
    QAudioBuffer read() override;
    void setAudioFormat(const QAudioFormat& format0) override;
    void setSourceDevice(QIODevice* device0) override;
    void setSourceFilename(const QString& fileName0) override;
    QIODevice* sourceDevice() const override;
    QString sourceFilename() const override;
    void start() override;
    QAudioDecoder::State state() const override;
    void stop() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAudioDecoderControl_access : public QAudioDecoderControl
{
    jobject __qt_audioFormat(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_bufferAvailable(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jlong __qt_duration(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jlong __qt_position(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_read(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setAudioFormat_cref_QAudioFormat(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID format0);
    void __qt_setSourceDevice_QIODevice_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID device0);
    void __qt_setSourceFilename_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring fileName0);
    jobject __qt_sourceDevice(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_sourceFilename(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_start(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_state(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_stop(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QAUDIODECODERCONTROL_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QAudioDecoderControl_shell.h <==
#ifndef QAUDIODECODERCONTROL_SHELL_H
#define QAUDIODECODERCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qaudiodecodercontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qaudiobuffer.h>
#include <QtMultimedia/qaudiodecoder.h>
#include <QtMultimedia/qaudioformat.h>
#include <QtJambi/RegistryAPI>


class QAudioDecoderControl_shell : public QAudioDecoderControl, public QtJambiShellInterface
{
public:
    QAudioDecoderControl_shell(QObject* parent0 = nullptr);
    ~QAudioDecoderControl_shell() override;

    QAudioFormat audioFormat() const override;
    bool bufferAvailable() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    qint64 duration() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    qint64 position() const override;
    QAudioBuffer read() override;
    void setAudioFormat(const QAudioFormat& format0) override;
    void setSourceDevice(QIODevice* device0) override;
    void setSourceFilename(const QString& fileName0) override;
    QIODevice* sourceDevice() const override;
    QString sourceFilename() const override;
    void start() override;
    QAudioDecoder::State state() const override;
    void stop() override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAudioDecoderControl_access : public QAudioDecoderControl
{
    jobject __qt_audioFormat_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_bufferAvailable_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jlong __qt_duration_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jlong __qt_position_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_read(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setAudioFormat_cref_QAudioFormat(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID format0);
    void __qt_setSourceDevice_QIODevice_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID device0);
    void __qt_setSourceFilename_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring fileName0);
    jobject __qt_sourceDevice_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_sourceFilename_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_start(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_state_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_stop(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QAUDIODECODERCONTROL_SHELL_H
